@@ -82,7 +82,7 @@ delete_catalog_dir (const char  *full_path,
 		rel_path = full_path + strlen (base_path) + 1;
 		g_free (base_path);
 
-		utf8_path = g_locale_to_utf8 (rel_path, -1, 0, 0, 0);
+		utf8_path = g_filename_to_utf8 (rel_path, -1, 0, 0, 0);
 
 		switch (gnome_vfs_result_from_errno ()) {
 		case GNOME_VFS_ERROR_DIRECTORY_NOT_EMPTY:
@@ -147,9 +147,13 @@ file_is_search_result (const char *fullpath)
 		return FALSE;
 	}
 
+	line[0] = 0;
 	fgets (line, sizeof (line), f);
 	fclose (f);
 
+	if (line[0] == 0)
+		return FALSE;
+
 	return strncmp (line, SEARCH_HEADER, strlen (SEARCH_HEADER)) == 0;
 }
 
@@ -504,7 +508,9 @@ catalog_add_item (Catalog *catalog,
 	g_return_if_fail (catalog != NULL);
 	g_return_if_fail (file_path != NULL);	
 
-	if (g_list_find (catalog->list, file_path) == NULL)
+	if (g_list_find_custom (catalog->list, 
+				file_path, 
+				(GCompareFunc) strcmp) == NULL)
 		catalog->list = g_list_prepend (catalog->list, 
 						g_strdup (file_path));
 }
