@@ -106,10 +106,10 @@ path_list_handle_free (PathListHandle *handle)
 
 static void
 directory_load_cb (GnomeVFSAsyncHandle *handle,
-		   GnomeVFSResult result,
-		   GList *list,
-		   guint entries_read,
-		   gpointer data)
+		   GnomeVFSResult       result,
+		   GList               *list,
+		   guint                entries_read,
+		   gpointer             data)
 {
 	PathListData *pli;
 	GList *node;
@@ -1008,21 +1008,71 @@ file_is_hidden (const gchar *name)
 }
 
 
+static const char *
+get_extension (const char *path)
+{
+	int         len;
+	int         p;
+	const char *ptr = path;
+
+	if (! path) 
+		return NULL;
+
+	len = strlen (path);
+	if (len <= 1) 
+		return NULL;
+
+	p = len - 1;
+	while ((ptr[p] != '.') && (p >= 0)) 
+		p--;
+
+	if (p < 0)
+		return NULL;
+
+	return path + p;
+}
+
+
+static char*
+get_sample_name (const char *filename)
+{
+	const char *ext;
+	
+	ext = get_extension (filename);
+	if (ext == NULL)
+		return NULL;
+
+	return g_strconcat ("a", get_extension (filename), NULL);
+}
+
+
 gboolean
 file_is_image (const gchar *name,
 	       gboolean     fast_file_type)
 {
-	const char *result;
+	const char *result = NULL;
 	gboolean    is_an_image;
 
 	if (fast_file_type) {
-		char *n1 = g_filename_to_utf8 (name, -1, 0, 0, 0);
-		char *n2 = g_utf8_strdown (n1, -1);
-		char *n3 = g_filename_from_utf8 (n2, -1, 0, 0, 0);
-		result = gnome_vfs_mime_type_from_name_or_default (n3, NULL);
-		g_free (n3);
-		g_free (n2);
-		g_free (n1);
+		char *filename, *n1;
+
+		filename = get_sample_name (name);
+		if (filename == NULL)
+			return FALSE;
+
+		n1 = g_filename_to_utf8 (filename, -1, 0, 0, 0);
+		if (n1 != NULL) {
+			char *n2, *n3;
+			n2 = g_utf8_strdown (n1, -1);
+			n3 = g_filename_from_utf8 (n2, -1, 0, 0, 0);
+
+			if (n3 != NULL)
+				result = gnome_vfs_mime_type_from_name_or_default (n3, NULL);
+
+			g_free (n3);
+			g_free (n2);
+			g_free (n1);
+		}
 	} else 
 		result = gnome_vfs_get_file_mime_type (name, NULL, FALSE);
 
@@ -1038,19 +1088,23 @@ file_is_image (const gchar *name,
 }
 
 
-gboolean 
-image_is_jpeg (const char *name)
+static gboolean 
+image_is_type (const char *name,
+	       const char *type)
 {
-	const char *result;
+	const char *result = NULL;
 
 	if (eel_gconf_get_boolean (PREF_FAST_FILE_TYPE, TRUE)) {
 		char *n1 = g_filename_to_utf8 (name, -1, 0, 0, 0);
-		char *n2 = g_utf8_strdown (n1, -1);
-		char *n3 = g_filename_from_utf8 (n2, -1, 0, 0, 0);
-		result = gnome_vfs_mime_type_from_name_or_default (n3, NULL);
-		g_free (n3);
-		g_free (n2);
-		g_free (n1);
+		if (n1 != NULL) {
+			char *n2 = g_utf8_strdown (n1, -1);
+			char *n3 = g_filename_from_utf8 (n2, -1, 0, 0, 0);
+			if (n3 != NULL)
+				result = gnome_vfs_mime_type_from_name_or_default (file_name_from_path (n3), NULL);
+			g_free (n3);
+			g_free (n2);
+			g_free (n1);
+		}
 	} else 
 		result = gnome_vfs_get_file_mime_type (name, NULL, FALSE);
 	
@@ -1058,7 +1112,21 @@ image_is_jpeg (const char *name)
 	if (result == NULL)
 		return FALSE;
 
-	return (strcmp (result, "image/jpeg") == 0);
+	return (strcmp (result, type) == 0);
+}
+
+
+gboolean 
+image_is_jpeg (const char *name)
+{
+	return image_is_type (name, "image/jpeg");
+}
+
+
+gboolean 
+image_is_gif (const char *name)
+{
+	return image_is_type (name, "image/gif");
 }
 
 
@@ -1600,6 +1668,9 @@ new_path_from_uri (GnomeVFSURI *uri)
 	char *path;
 	char *unescaped_path;
 
+	if (uri == NULL)
+		return NULL;
+
 	path = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);
 	unescaped_path = gnome_vfs_unescape_string (path, NULL);
 	g_free (path);
@@ -1617,6 +1688,7 @@ resolve_all_symlinks (const char  *text_uri,
 	GnomeVFSFileInfo *info;
 	const char       *p;
 	int               n_followed_symlinks = 0;
+	gboolean          first_level = TRUE;
 
 	*resolved_text_uri = NULL;
 
@@ -1652,6 +1724,7 @@ resolve_all_symlinks (const char  *text_uri,
 			   info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_SYMLINK_NAME) {
 			GnomeVFSURI *resolved_uri;
 			char        *tmp_resolved_text_uri = NULL;
+			char        *symbolic_link = NULL;
 
 			n_followed_symlinks++;
 			if (n_followed_symlinks > MAX_SYMLINKS_FOLLOWED) {
@@ -1660,7 +1733,13 @@ resolve_all_symlinks (const char  *text_uri,
 				goto out;
 			}
 
-			resolved_uri = gnome_vfs_uri_resolve_relative (new_uri, info->symlink_name);
+			if (first_level && (info->symlink_name[0] != '/')) 
+				symbolic_link = g_strconcat ("/", info->symlink_name);
+			else 
+				symbolic_link = g_strdup (info->symlink_name);
+			resolved_uri = gnome_vfs_uri_resolve_relative (new_uri, symbolic_link);
+			g_free (symbolic_link);
+
 			tmp_resolved_text_uri = new_path_from_uri (resolved_uri);
 			gnome_vfs_uri_unref (resolved_uri);
 
@@ -1676,6 +1755,7 @@ resolve_all_symlinks (const char  *text_uri,
 
 			p = my_text_uri;
 		}
+		first_level = FALSE;
 
 		gnome_vfs_uri_unref (new_uri); 
 	}
