@@ -1302,7 +1302,7 @@ gth_file_view_list_init (GthFileViewList *gfv_list)
 GType
 gth_file_view_list_get_type (void)
 {
-	static guint type = 0;
+	static GType type = 0;
 
 	if (! type) {
 		GTypeInfo type_info = {
