@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 The Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -65,4 +65,9 @@ gboolean   _gdk_pixbuf_savev                  (GdkPixbuf    *pixbuf,
 					       char        **values,
 					       GError      **error);
 
+gboolean   scale_keepping_ratio               (int *width,
+					       int *height,
+					       int  max_width,
+					       int  max_height);
+
 #endif
