@@ -458,10 +458,22 @@ update_info (DialogData *data)
 
 			gtk_widget_show (data->progress_info_box);
 		} 
+
+		gdk_flush ();
 	}
 }
 
 
+static void
+main_dialog_set_sensitive (DialogData *data,
+			   gboolean    value)
+{
+	gtk_widget_set_sensitive (data->select_model_button, value);
+	gtk_widget_set_sensitive (data->import_reload_button, value);
+	gtk_widget_set_sensitive (data->import_delete_button, value);
+}
+
+
  /**/
 
 
@@ -526,9 +538,13 @@ async_operation_step (gpointer callback_data)
 		g_mutex_lock (aodata->data->yes_or_no);
 		aodata->data->async_operation = FALSE;
 		g_mutex_unlock (aodata->data->yes_or_no);
+
+		main_dialog_set_sensitive (aodata->data, TRUE);
+
 		if (aodata->done_func != NULL)
 			(*aodata->done_func) (aodata, aodata->data);
 		g_free (aodata);
+
 		return FALSE;
 	}
 	
@@ -557,6 +573,8 @@ async_operation_start (AsyncOperationData *aodata)
 	if (aodata->init_func)
 		(*aodata->init_func) (aodata, aodata->data);
 
+	main_dialog_set_sensitive (aodata->data, FALSE);
+
 	g_mutex_lock (aodata->data->yes_or_no);
 	aodata->data->async_operation = TRUE;
 	aodata->data->interrupted = FALSE;
@@ -581,7 +599,7 @@ static int
 get_default_icon_size (GtkWidget *widget)
 {
         int icon_width, icon_height;
-                                                                                
+
         gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (widget),
                                            GTK_ICON_SIZE_DIALOG,
                                            &icon_width, &icon_height);
@@ -815,6 +833,9 @@ set_camera_model (DialogData *data,
 	} 
 
 	if (r >= 0) {
+		eel_gconf_set_string (PREF_PHOTO_IMPORT_MODEL, model);
+		eel_gconf_set_string (PREF_PHOTO_IMPORT_PORT, port);
+
 		_gtk_label_set_locale_text (GTK_LABEL (data->camera_model_label), model);
 		gtk_image_set_from_pixbuf (GTK_IMAGE (data->progress_camera_image), data->camera_present_pixbuf);
 		load_images_preview (data);
@@ -841,7 +862,7 @@ autodetect_camera (DialogData *data)
 	const char *model = NULL, *port = NULL;
 
 	data->current_op = GTH_IMPORTER_OP_AUTO_DETECT;
-
+		
 	gp_list_new (&list);
 
 	gp_abilities_list_detect (data->abilities_list,
@@ -858,7 +879,7 @@ autodetect_camera (DialogData *data)
 		model = NULL;
 		port = NULL;
 	}
-
+		
 	set_camera_model (data, model, port);
 
 	gp_list_free (list);
@@ -1147,6 +1168,11 @@ save_image (DialogData *data,
 			data->delete_list = g_list_prepend (data->delete_list, 
 							    g_strdup (camera_path));
 		add_categories_to_image (data, local_path);
+	} else {
+		g_mutex_lock (data->yes_or_no);
+		data->error = TRUE;
+		data->interrupted = TRUE;
+		g_mutex_unlock (data->yes_or_no);
 	}
 	
 	g_free (local_path);
@@ -1237,13 +1263,15 @@ save_images__done (AsyncOperationData *aodata,
 		   DialogData         *data)
 {
 	gboolean            interrupted;
+	gboolean            error;
 	AsyncOperationData *new_aodata;
 
 	g_mutex_lock (data->yes_or_no);
 	interrupted = data->interrupted;
+	error = data->error;
 	g_mutex_unlock (data->yes_or_no);
 
-	if (interrupted)
+	if (interrupted || error)
 		return;
 
 	new_aodata = async_operation_new (data->delete_list,
@@ -1282,6 +1310,7 @@ ok_clicked_cb (GtkButton  *button,
 	GList              *sel_list;
 	gboolean            error;
 	AsyncOperationData *aodata;
+	GnomeVFSFileSize    total_size = 0;
 
 	if (!data->camera_setted) {
 		display_error_dialog (data,
@@ -1291,6 +1320,7 @@ ok_clicked_cb (GtkButton  *button,
 	}
 
 	/**/
+
 	g_free (data->local_folder);
 
 	data->local_folder = get_folder_name (data);
@@ -1305,9 +1335,21 @@ ok_clicked_cb (GtkButton  *button,
 
 	/**/
 
+	g_mutex_lock (data->yes_or_no);
+	error = data->error;
+	g_mutex_unlock (data->yes_or_no);
+
+	if (error) {
+		update_info (data);
+		return;
+	}
+
 	sel_list = gth_image_list_get_selection (GTH_IMAGE_LIST (data->image_list));
-	if (sel_list == NULL)
+	if (sel_list == NULL) {
 		sel_list = gth_image_list_get_list (GTH_IMAGE_LIST (data->image_list));
+		g_list_foreach (sel_list, (GFunc) file_data_ref, NULL);
+	}
+
 	if (sel_list != NULL) {
 		for (scan = sel_list; scan; scan = scan->next) {
 			FileData   *fdata = scan->data;
@@ -1319,33 +1361,71 @@ ok_clicked_cb (GtkButton  *button,
 		file_data_list_free (sel_list);
 	} 
 
-	g_mutex_lock (data->yes_or_no);
-	error = data->error;
-	g_mutex_unlock (data->yes_or_no);
-
-	if (error) {
-		update_info (data);
-		return;
-	}
-	
 	if (file_list == NULL) {
 		display_error_dialog (data,
 				      _("Could not import photos"), 
 				      _("No images found"));
 		return;
 	}
-	
+
 	if (! ensure_dir_exists (data->local_folder, 0755)) {
+		char *utf8_path;
 		char *msg;
-		
+		utf8_path = g_filename_to_utf8 (data->local_folder, -1, NULL, NULL, NULL);
 		msg = g_strdup_printf (_("Could not create the folder \"%s\": %s"),
-				       data->local_folder,
-				       errno_to_string());
+				       utf8_path,
+				       errno_to_string ());
 		display_error_dialog (data, _("Could not import photos"), msg);
+
+		g_free (utf8_path);
 		g_free (msg);
-		
 		g_free (data->local_folder);
 		data->local_folder = NULL;
+		path_list_free (file_list);
+		return; 
+	}
+
+	if (! check_permissions (data->local_folder, R_OK | W_OK | X_OK)) {
+		char *utf8_path;
+		char *msg;
+		utf8_path = g_filename_to_utf8 (data->local_folder, -1, NULL, NULL, NULL);
+		msg = g_strdup_printf (_("You don't have the right permissions to create images in the folder \"%s\""), utf8_path);
+
+		display_error_dialog (data, _("Could not import photos"), msg);
+				       
+		g_free (utf8_path);
+		g_free (msg);
+		g_free (data->local_folder);
+		data->local_folder = NULL;
+		path_list_free (file_list);
+		return;
+	} 
+
+	for (scan = file_list; scan; scan = scan->next) {
+		const char     *camera_path = scan->data;
+		CameraFileInfo  info;
+		char           *camera_folder;
+		const char     *camera_filename;
+
+		camera_folder = remove_level_from_path (camera_path);
+		camera_filename = file_name_from_path (camera_path);
+		gp_camera_file_get_info (data->camera, 
+					 camera_folder, 
+					 camera_filename,
+					 &info,
+					 data->context);
+		g_free (camera_folder);
+		total_size += (GnomeVFSFileSize) info.file.size;
+	}
+
+	if (get_dest_free_space (data->local_folder) < total_size) {
+		display_error_dialog (data, 
+				      _("Could not import photos"), 
+				      "Not enough free space left on disk"); /* FIXME: mark for translation. */
+
+		g_free (data->local_folder);
+		data->local_folder = NULL;
+		path_list_free (file_list);
 		return; 
 	}
 
@@ -1498,8 +1578,20 @@ check_thread (gpointer cb_data)
 		task_terminated (data);
 
 		switch (data->current_op) {
-		case GTH_IMPORTER_OP_LIST_ABILITIES:
-			autodetect_camera (data);
+		case GTH_IMPORTER_OP_LIST_ABILITIES: 
+			if (! autodetect_camera (data)) {
+				char *camera_model;
+				char *camera_port;
+				
+				camera_model = eel_gconf_get_string (PREF_PHOTO_IMPORT_MODEL, NULL);
+				camera_port = eel_gconf_get_string (PREF_PHOTO_IMPORT_PORT, NULL);
+
+				if ((camera_model != NULL) && (camera_port != NULL))
+					set_camera_model (data, camera_model, camera_port);
+
+				g_free (camera_model);
+				g_free (camera_port);
+			}
 			break;
 		default:
 			break;
